@@ -36,13 +36,13 @@
 #include "breakpointdetails.h"
 #include "../breakpoint/breakpoint.h"
 #include "../breakpoint/breakpointmodel.h"
-#include "../../shell/debugcontroller.h"
+#include <interfaces/idebugcontroller.h>
 
 #define IF_DEBUG(x)
 
 using namespace KDevelop;
 
-BreakpointWidget::BreakpointWidget(DebugController *controller, QWidget *parent)
+BreakpointWidget::BreakpointWidget(IDebugController *controller, QWidget *parent)
 : QWidget(parent), firstShow_(true), m_debugController(controller)
 {
     setWindowTitle(i18n("Debugger Breakpoints"));
