@@ -40,7 +40,6 @@
 #include "aliasdeclaration.h"
 #include "abstractfunctiondeclaration.h"
 #include "uses.h"
-#include "arrayhelpers.h"
 #include "topducontextdata.h"
 #include "duchainregister.h"
 #include "topducontextdynamicdata.h"
@@ -143,17 +142,6 @@ void removeFromVector(QVector<T>& vec, const T& t) {
 
 QMutex importStructureMutex(QMutex::Recursive);
 
-template<class Container>
-bool removeOneImport(Container& container, const DUContext* value) {
-  for(int a = 0; a < container.size(); ++a) {
-    if(container[a].context() == value) {
-      removeFromArray(container, a);
-      return true;
-    }
-  }
-  return false;
-}
-
 //Contains data that is not shared among top-contexts that share their duchain entries
 class TopDUContextLocalPrivate {
 public:
@@ -221,7 +209,7 @@ public:
         addImportedContextRecursively(top, false, true);
       }
     }
-    FOREACH_FUNCTION(IndexedDUContext importer, m_ctxt->d_func()->m_importers) {
+    FOREACH_FUNCTION(const IndexedDUContext& importer, m_ctxt->d_func()->m_importers) {
       if(DUChain::self()->isInMemory(importer.topContextIndex())) {
         Q_ASSERT(importer.context());
         TopDUContext* top = importer.context()->topContext();
@@ -947,7 +935,7 @@ bool TopDUContext::findDeclarationsInternal(const SearchItem::PtrList& identifie
   ENSURE_CAN_READ
 
 #ifdef DEBUG_SEARCH
-  FOREACH_ARRAY(SearchItem::Ptr idTree, identifiers)
+  FOREACH_ARRAY(const SearchItem::Ptr& idTree, identifiers)
       foreach(const QualifiedIdentifier &id, idTree->toList())
         kDebug() << "searching item" << id.toString();
 #endif
@@ -1064,7 +1052,7 @@ bool TopDUContext::applyAliases( const QualifiedIdentifier& previous, const Sear
               return false;
           }else{
             //Create an identifiers where namespace-alias part is replaced with the alias target
-            FOREACH_ARRAY(SearchItem::Ptr item, identifier->next)
+            FOREACH_ARRAY(const SearchItem::Ptr& item, identifier->next)
               if(!applyAliases(importIdentifier, item, accept, position, canBeNamespace, &info, recursionDepth+1))
                 return false;
           }
@@ -1078,7 +1066,7 @@ bool TopDUContext::applyAliases( const QualifiedIdentifier& previous, const Sear
       if(!accept(id)) //We're at the end of a qualified identifier, accept it
         return false;
     } else {
-      FOREACH_ARRAY(SearchItem::Ptr next, identifier->next)
+      FOREACH_ARRAY(const SearchItem::Ptr& next, identifier->next)
         if(!applyAliases(id, next, accept, position, canBeNamespace, 0, recursionDepth+1))
           return false;
     }
@@ -1149,7 +1137,7 @@ void TopDUContext::applyAliases( const SearchItem::PtrList& identifiers, Accepto
 {
   QualifiedIdentifier emptyId;
   
-  FOREACH_ARRAY(SearchItem::Ptr item, identifiers)
+  FOREACH_ARRAY(const SearchItem::Ptr& item, identifiers)
     applyAliases(emptyId, item, acceptor, position, canBeNamespace, 0, 0);
 }
 
