@@ -99,6 +99,17 @@ void ProblemHighlighter::textHintRequested(const KTextEditor::Cursor& pos, QStri
     }
 }
 
+void removeWatcher(const QList<SmartRange*> ranges, SmartRangeWatcher* watcher)
+{
+    foreach(SmartRange* range, ranges) {
+        Q_ASSERT(!range->watchers().contains(watcher));
+        foreach(SmartRange* child, range->childRanges()) {
+            Q_ASSERT(child->watchers().contains(watcher));
+            child->removeWatcher(watcher);
+        }
+    }
+}
+
 ProblemHighlighter::~ProblemHighlighter()
 {
     if(m_topHLRanges.isEmpty() || !m_document)
@@ -108,8 +119,10 @@ ProblemHighlighter::~ProblemHighlighter()
     editor.setCurrentUrl(IndexedString(m_document->url()), true);
 
     LockedSmartInterface iface = editor.smart();
-    if (iface)
+    if (iface) {
+        removeWatcher(m_topHLRanges, this);
         qDeleteAll(m_topHLRanges);
+    }
 }
 
 void ProblemHighlighter::setProblems(const QList<KDevelop::ProblemPointer>& problems)
@@ -127,6 +140,7 @@ void ProblemHighlighter::setProblems(const QList<KDevelop::ProblemPointer>& prob
     
     m_problems = problems;
 
+    removeWatcher(m_topHLRanges, this);
     qDeleteAll(m_topHLRanges);
     m_topHLRanges.clear();
     m_problemsForRanges.clear();
