@@ -168,18 +168,30 @@ void ProjectManagerView::locateCurrentDocument()
     // We should _never_ get a null pointer for the document, as
     // the action is only enabled when there is an active document.
     Q_ASSERT(doc); 
-   
+
+    QModelIndex bestMatch;
     foreach (IProject* proj, ICore::self()->projectController()->projects()) {
         foreach (KDevelop::ProjectFileItem* item, proj->filesForUrl(doc->url())) {
             QModelIndex index = m_modelFilter->proxyIndexFromItem(item);
             if (index.isValid()) {
-                m_ui->projectTreeView->setCurrentIndex(index);
-                m_ui->projectTreeView->expand(index);
-                m_ui->projectTreeView->scrollTo(index);
-                return;
+                if (!bestMatch.isValid()) {
+                    bestMatch = index;
+                } else if (KDevelop::ProjectFolderItem* folder = dynamic_cast<KDevelop::ProjectFolderItem*>(item->parent())) {
+                    // prefer files in their real folders over the 'copies' in the target folders
+                    if (!folder->target()) {
+                        bestMatch = index;
+                        break;
+                    }
+                }
             }
         }
     }
+    if (bestMatch.isValid()) {
+        m_ui->projectTreeView->clearSelection();
+        m_ui->projectTreeView->setCurrentIndex(bestMatch);
+        m_ui->projectTreeView->expand(bestMatch);
+        m_ui->projectTreeView->scrollTo(bestMatch);
+    }
 }
 
 void ProjectManagerView::openUrl( const KUrl& url )
