@@ -52,9 +52,6 @@ SnippetCompletionModel::~SnippetCompletionModel()
 QVariant SnippetCompletionModel::data( const QModelIndex& idx, int role ) const
 {
     // grouping of snippets
-    if (role == KTextEditor::CodeCompletionModel::InheritanceDepth) {
-        return 1;
-    }
     if (!idx.parent().isValid()) {
         if (role == Qt::DisplayRole) {
             return i18n("Snippets");
@@ -62,6 +59,9 @@ QVariant SnippetCompletionModel::data( const QModelIndex& idx, int role ) const
         if (role == KTextEditor::CodeCompletionModel::GroupRole) {
             return Qt::DisplayRole;
         }
+        if (role == KTextEditor::CodeCompletionModel::InheritanceDepth) {
+            return 800;
+        }
         return QVariant();
     }
     // snippets
@@ -156,4 +156,43 @@ int SnippetCompletionModel::rowCount (const QModelIndex & parent) const {
         return m_snippets.count(); // only the children
     }
 }
+KTextEditor::Range SnippetCompletionModel::completionRange(KTextEditor::View* view, const KTextEditor::Cursor& position)
+{
+    const QString& line = view->document()->line(position.line());
+    KTextEditor::Range range(position, position);
+    // include everything non-space before
+    for ( int i = position.column() - 1; i >= 0; --i ) {
+        if ( line.at(i).isSpace() ) {
+            break;
+        } else {
+            range.start().setColumn(i);
+        }
+    }
+    // include everything non-space after
+    for ( int i = position.column() + 1; i < line.length(); ++i ) {
+        if ( line.at(i).isSpace() ) {
+            break;
+        } else {
+            range.end().setColumn(i);
+        }
+    }
+    return range;
+}
+
+bool SnippetCompletionModel::shouldAbortCompletion(KTextEditor::View* view, const KTextEditor::SmartRange& range, const QString& currentCompletion)
+{
+    if(view->cursorPosition() < range.start() || view->cursorPosition() > range.end()) {
+        return true; //Always abort when the completion-range has been left
+    }
+
+    for ( int i = 0; i < currentCompletion.length(); ++i ) {
+        if ( currentCompletion.at(i).isSpace() ) {
+            return true;
+        }
+    }
+    // else it's valid
+    return false;
+}
+
+
 #include "snippetcompletionmodel.moc"
