@@ -24,6 +24,8 @@
 #include "shellexport.h"
 #include <interfaces/icore.h>
 
+class KSplashScreen;
+
 namespace KDevelop {
 
 class UiController;
@@ -48,8 +50,10 @@ public:
 
     static QString version();
 
-    /** Initialize the core of the kdevplatform application */
-    static void initialize(Setup mode=Default);
+    /** Initialize the core of the kdevplatform application
+      * returns false if the initialization fails, which may happen
+      * if the same session is already active in another instance */
+    static bool initialize(KSplashScreen* splash = 0, Setup mode=Default);
 
     /**
      * \brief Provide access an instance of Core
@@ -127,6 +131,10 @@ public:
 
     /** @return working set controller */
     WorkingSetController* workingSetControllerInternal();
+
+    /** @return the real source formatter controller */
+    SourceFormatterController* sourceFormatterControllerInternal();
+
     /**
      * @return session controller
      * @internal
@@ -140,6 +148,8 @@ public:
 
     void cleanup();
 
+    virtual bool shuttingDown() const;    
+    
     Core::Setup setupFlags() const;
 protected:
     Core( KDevelop::CorePrivate* dd, QObject* parent = 0 );
