@@ -431,7 +431,7 @@ void RunController::setupActions()
     ac->addAction("run_profile", d->profileAction);
     connect(d->profileAction, SIGNAL(triggered(bool)), this, SLOT(slotProfile()));
 
-    action = d->stopAction = new KActionMenu( KIcon("dialog-close"), i18n("Stop Jobs"), this);
+    action = d->stopAction = new KActionMenu( KIcon("process-stop"), i18n("Stop Jobs"), this);
     action->setIconText(i18nc("Short text for 'Stop Jobs' used in the toolbar", "Stop"));
     action->setShortcut(Qt::Key_Escape);
     action->setToolTip(i18n("Stop all currently running jobs"));
@@ -510,16 +510,20 @@ void KDevelop::RunController::registerJob(KJob * job)
         return;
 
     if (!d->jobs.contains(job)) {
-        KAction* stopJobAction = new KAction(job->objectName().isEmpty() ? i18n("Unnamed job") : job->objectName(), this);
-        stopJobAction->setData(QVariant::fromValue(static_cast<void*>(job)));
-        d->stopAction->addAction(stopJobAction);
-        connect( job, SIGNAL(finished(KJob*)), SLOT(finished(KJob*)) );
-        connect (stopJobAction, SIGNAL(triggered(bool)), SLOT(slotKillJob()));
+        KAction* stopJobAction = 0;
+        if (Core::self()->setupFlags() != Core::NoUi) {
+            stopJobAction = new KAction(job->objectName().isEmpty() ? i18n("Unnamed job") : job->objectName(), this);
+            stopJobAction->setData(QVariant::fromValue(static_cast<void*>(job)));
+            d->stopAction->addAction(stopJobAction);
+            connect (stopJobAction, SIGNAL(triggered(bool)), SLOT(slotKillJob()));
 
-        job->setUiDelegate( new KDialogJobUiDelegate() );
+            job->setUiDelegate( new KDialogJobUiDelegate() );
+        }
 
         d->jobs.insert(job, stopJobAction);
 
+        connect( job, SIGNAL(finished(KJob*)), SLOT(finished(KJob*)) );
+
         IRunController::registerJob(job);
 
         emit jobRegistered(job);
@@ -537,7 +541,9 @@ void KDevelop::RunController::unregisterJob(KJob * job)
     Q_ASSERT(d->jobs.contains(job));
 
     // Delete the stop job action
-    d->jobs.take(job)->deleteLater();
+    QAction *action = d->jobs.take(job);
+    if (action)
+        action->deleteLater();
 
     checkState();
 
@@ -560,7 +566,8 @@ void KDevelop::RunController::checkState()
         emit runStateChanged(d->state);
     }
 
-    d->stopAction->setEnabled(running);
+    if (Core::self()->setupFlags() != Core::NoUi)
+        d->stopAction->setEnabled(running);
 }
 
 void KDevelop::RunController::stopAllProcesses()
