@@ -39,7 +39,7 @@ public:
         , m_doc( doc )
     {
         setFlags(Qt::ItemIsUserCheckable | flags());
-        setData(Qt::CheckStateRole, true);
+        setData(Qt::CheckStateRole, Qt::Checked);
         setText(m_doc->url().prettyUrl());
     }
 
@@ -70,7 +70,7 @@ KSaveSelectDialog::KSaveSelectDialog( const QList<IDocument*>& files, QWidget *
 //     m_listWidget->header()->hide();
 //     m_listWidget->setResizeMode( QListView::LastColumn );
 
-    setButtonGuiItem( Ok, KGuiItem(i18n("Save &Selected"), QString(), i18n("Saves all selected files")) );
+    setButtonGuiItem( Ok, KGuiItem(i18n("Save &Selected"), KIcon("document-save-all"), i18n("Saves all selected files")) );
     setButtonText( User1, i18n("Save &None") );
     setButtonToolTip( User1, i18n("Discard all modifications") );
     setDefaultButton( Ok );
