@@ -44,9 +44,6 @@ protected:
     void setActiveView(MainWindow *w, View *view);
     /**Sets the active toolview for the mainwindow and focuses it.*/
     void setActiveToolView(MainWindow *w, View *view);
-
-    /**Sets the status icon for the given \a view in the \a mainWindow to \a icon.*/
-    void setStatusIcon(MainWindow* w, View* view, const QIcon& icon);
 };
 
 }
